@@ -33,33 +33,24 @@ function getCsrfToken(){
     if (call.stack.length) {
       let s = call.stack;
       call.stack = [];
-      var xhttp = new XMLHttpRequest();
-      xhttp.open("POST", "pathToEndpoint");
-      xhttp.withCredentials = true;
-      xhttp.setRequestHeader("Content-Type", "application/json;charset=UTF-8");
-      xhttp.setRequestHeader("X-CSRFToken", getCsrfToken());
-      xhttp.onload = function (e) {
-        call.resolve(s, JSON.parse(e.target.response));
-      };
-      xhttp.onerror = function () {
-        call.reject(s);
-      };
-      xhttp.send(JSON.stringify(s));
-      console.log(JSON.stringify(s, null, 2));
+      fetch("pathToEndpoint", {
+        "headers": {
+          "Content-Type": "application/json;charset=UTF-8",
+          "X-CSRFToken": getCsrfToken()
+        },
+        "method": "POST",
+        "credentials": "include",
+        "body": JSON.stringify(s)
+      }).then(
+        async r => call.resolve(s, await r.json()),
+        async r => call.reject(s, r)
+      )
     }
   },
   resolve: function (callStack, serverResponse) {
     serverResponse.forEach((element, i) => {
       callStack[i].promise.resolve(element);
     });
-    console.log(
-      "Calles resolved:\n--------------\n",
-      "Request:\n",
-      JSON.stringify(callStack, null, 2),
-      "\n--------------\n",
-      "Response\n",
-      JSON.stringify(serverResponse, null, 2)
-    );
   },
   reject: function (callStack) {
     callStack.forEach((c) => {
